@@ -195,6 +195,7 @@ public:
   int32_t UnreadMessageCount() override { return m_UnreadMessageCount; }
   void MarkMessagesRead() override { m_UnreadMessageCount = 0; }
   void AddMessages(const rdcarray<DebugMessage> &msgs) override;
+  void ClearMessages() override;
 
   void ConnectToRemoteServer(RemoteHost host) override;
 
@@ -204,6 +205,8 @@ public:
   void SetBookmark(const EventBookmark &mark) override;
   void RemoveBookmark(uint32_t EID) override;
 
+  void DelayedCallback(uint32_t milliseconds, std::function<void()> callback) override;
+
   IMainWindow *GetMainWindow() override;
   IEventBrowser *GetEventBrowser() override;
   IAPIInspector *GetAPIInspector() override;
