@@ -274,6 +274,26 @@ VulkanShaderCache::VulkanShaderCache(WrappedVulkan *driver)
   rdcspv::CompilationSettings compileSettings;
   compileSettings.lang = rdcspv::InputLanguage::VulkanGLSL;
 
+  uint32_t toolCount = 0;
+  if(ObjDisp(driver->GetPhysDev())->GetPhysicalDeviceToolProperties != NULL)
+  {
+    ObjDisp(driver->GetPhysDev())
+        ->GetPhysicalDeviceToolProperties(Unwrap(driver->GetPhysDev()), &toolCount, NULL);
+    rdcarray<VkPhysicalDeviceToolProperties> tools;
+    tools.resize(toolCount);
+    ObjDisp(driver->GetPhysDev())
+        ->GetPhysicalDeviceToolProperties(Unwrap(driver->GetPhysDev()), &toolCount, tools.data());
+
+    for(const VkPhysicalDeviceToolProperties &t : tools)
+    {
+      if(rdcstr(t.name) == "RenderDoc")
+      {
+        RDCLOG("Enabling debug info for self-captured shaders");
+        compileSettings.debugInfo = true;
+      }
+    }
+  }
+
   m_Buffer2MSSupported = PassesChecks(builtinShaders[(size_t)BuiltinShader::Buffer2MSCS], driver,
                                       driverVersion, availFeatures);
 
@@ -323,7 +343,10 @@ VulkanShaderCache::VulkanShaderCache(WrappedVulkan *driver)
         // determine if we can skip the call to GenerateGLSLShader (which calls out to glslang).
         // Otherwise we'll use the cached SPIR-V generated by the previous call using the same
         // source & defines.
-        inputHash = strhash("inputHashVersion1", inputHash);
+        inputHash = strhash("inputHashVersion2", inputHash);
+
+        if(compileSettings.debugInfo)
+          inputHash = strhash("debug", inputHash);
 
         rdcstr err;
 
@@ -1110,6 +1133,22 @@ void VulkanShaderCache::MakeGraphicsPipelineInfo(VkGraphicsPipelineCreateInfo &p
     ret.pNext = &VkPipelineRobustnessCreateInfo;
   }
 
+  static VkPipelineFragmentDensityMapLayeredCreateInfoVALVE
+      VkPipelineFragmentDensityMapLayeredCreateInfoVALVE = {
+          VK_STRUCTURE_TYPE_PIPELINE_FRAGMENT_DENSITY_MAP_LAYERED_CREATE_INFO_VALVE,
+      };
+
+  // we only need to specify vertex input robustness, all per-shader robustness is handled via
+  // pNexts on the stages above
+  if(pipeInfo.maxFragmentDensityMapLayers)
+  {
+    VkPipelineFragmentDensityMapLayeredCreateInfoVALVE.maxFragmentDensityMapLayers =
+        pipeInfo.maxFragmentDensityMapLayers;
+
+    VkPipelineFragmentDensityMapLayeredCreateInfoVALVE.pNext = ret.pNext;
+    ret.pNext = &VkPipelineFragmentDensityMapLayeredCreateInfoVALVE;
+  }
+
   pipeCreateInfo = ret;
 }
 
